@@ -386,6 +386,13 @@ class Query(bigquery_command.BigqueryCmd):
         ' query engine decides to bypass job creation.',
         flag_values=fv,
     )
+    flags.DEFINE_integer(
+        'max_slots',
+        None,
+        'Cap on target rate of slot consumption by the query. Requires'
+        ' --alpha=query_max_slots to be specified.',
+        flag_values=fv,
+    )
     self.reservation_id_for_a_job_flag = (
         frontend_flags.define_reservation_id_for_a_job(flag_values=fv)
     )
@@ -597,6 +604,11 @@ class Query(bigquery_command.BigqueryCmd):
       kwds['reservation_id'] = self.reservation_id_for_a_job_flag.value
     if self.job_timeout_ms:
       kwds['job_timeout_ms'] = self.job_timeout_ms
+    if self.max_slots is not None:
+      utils_flags.fail_if_not_using_alpha_feature(
+          bq_flags.AlphaFeatures.QUERY_MAX_SLOTS
+      )
+      kwds['max_slots'] = self.max_slots
     if self.rpc:
       if self.allow_large_results:
         raise app.UsageError(
@@ -618,13 +630,17 @@ class Query(bigquery_command.BigqueryCmd):
         raise app.UsageError('continuous cannot be specified in rpc mode.')
       kwds['job_creation_mode'] = self.job_creation_mode
       kwds['max_results'] = self.max_rows
+      use_full_timestamp = False
       logging.debug('Calling client_job.RunQueryRpc(%s, %s)', query, kwds)
-      fields, rows, execution = client_job.RunQueryRpc(client, query, **kwds)
+      fields, rows, execution = client_job.RunQueryRpc(
+          client, query,
+          **kwds
+      )
       if self.dry_run:
         frontend_utils.PrintDryRunInfo(execution)
       else:
         bq_cached_client.Factory.ClientTablePrinter.GetTablePrinter().PrintTable(
-            fields, rows, use_full_timestamp=False
+            fields, rows, use_full_timestamp=use_full_timestamp
         )
         # If we are here, the job succeeded, but print warnings if any.
         frontend_utils.PrintJobMessages(execution)
@@ -633,6 +649,8 @@ class Query(bigquery_command.BigqueryCmd):
         kwds['write_disposition'] = 'WRITE_APPEND'
       if self.destination_table and self.replace:
         kwds['write_disposition'] = 'WRITE_TRUNCATE'
+      if self.destination_table and self.replace_data:
+        kwds['write_disposition'] = 'WRITE_TRUNCATE_DATA'
       if self.require_cache:
         kwds['create_disposition'] = 'CREATE_NEVER'
       if (
@@ -825,6 +843,7 @@ class Query(bigquery_command.BigqueryCmd):
         and not frontend_utils.IsSuccessfulDmlOrDdlJob(printable_job_info)
         and not is_assert_job
     ):
+      use_full_timestamp = False
       # ReadSchemaAndJobRows can handle failed jobs, but cannot handle
       # a successful DML job if the destination table is already deleted.
       # DML, DDL, and ASSERT do not have query result, so skip
@@ -836,7 +855,7 @@ class Query(bigquery_command.BigqueryCmd):
           max_rows=self.max_rows,
       )
       bq_cached_client.Factory.ClientTablePrinter.GetTablePrinter().PrintTable(
-          fields, rows, use_full_timestamp=False
+          fields, rows, use_full_timestamp=use_full_timestamp
       )
     elif json_escape:
       print(
